@@ -330,9 +330,10 @@ class SlashedSubCommand(SlashedCommand, SlashSubcommand):
 class SlashedContext(Interaction, ContextCommand):
     def __init__(self, client, command: ContextCommand, data, user, param, guild_ids = None, guild_permissions = None) -> None:
         Interaction.__init__(self, client._connection, data, user)
-        ContextCommand.__init__(self, None, "EMPTY", guild_ids=guild_ids, guild_permissions=guild_permissions)
-        self.bot: Bot = client
+        ContextCommand.__init__(self, data["data"]["type"], None, "EMPTY", guild_ids=guild_ids, guild_permissions=guild_permissions)
         self._json = command.to_dict()
+        guild_permissions = guild_permissions or {}
+        self.bot: Bot = client
         self.guild_ids: List[int] = guild_ids
         """The guild_ids where the command is available"""
         self.param: Union[Message, discord.Member, discord.User] = param
@@ -380,7 +381,7 @@ class Message(discord.Message):
         self._payload = data
 
         self._state: ConnectionState = None
-        super().__init__(state=state, channel=channel, data=data)
+        discord.Message.__init__(self, state=state, channel=channel, data=data)
         self.components: List[Union[Button, LinkButton, SelectMenu]] = []
         """The components in the message
         
@@ -542,7 +543,7 @@ class Message(discord.Message):
             rows.append(c_row) 
         return rows
 
-    async def wait_for(self, event_name: Literal["select", "button", "component"], client, custom_id=MISSING, by=MISSING, check=lambda component: True, timeout=None) -> Union[PressedButton, SelectedMenu]:
+    async def wait_for(self, event_name: Literal["select", "button", "component"], client, custom_id=MISSING, by=MISSING, check=lambda component: True, timeout=None) -> Union[PressedButton, SelectedMenu, ComponentContext]:
         """Waits for a message component to be invoked in this message
 
         Parameters
@@ -591,21 +592,26 @@ class Message(discord.Message):
             except asyncio.TimeoutError:
                 # no button press was received in 20 seconds timespan
         """
-        if event_name.lower() in ["button", "select", "component"]:
-            def _check(com):
-                if com.message.id == self.id:
-                    statements = []
-                    if not _none(custom_id):
-                        statements.append(com.custom_id == custom_id)
-                    if not _none(by):
-                        statements.append(com.member.id == (by.id if hasattr(by, "id") else int(by)))
-                    if not _none(check):
-                        statements.append(check(com))
-                    return all(statements)
-                return False
-            if not isinstance(client, Bot):
-                raise WrongType("client", client, "discord.ext.commands.Bot")
-            return (await client.wait_for('button_press' if event_name.lower() == "button" else ("menu_select" if event_name.lower() == "menu" else "component"), check=_check, timeout=timeout))
+        def _check(com):
+            if com.message.id == self.id:
+                statements = []
+                if not _none(custom_id):
+                    statements.append(com.custom_id == custom_id)
+                if not _none(by):
+                    statements.append(com.member.id == (by.id if hasattr(by, "id") else int(by)))
+                if not _none(check):
+                    statements.append(check(com))
+                return all(statements)
+            return False
+        if not isinstance(client, Bot):
+            raise WrongType("client", client, "discord.ext.commands.Bot")
+        
+        if event_name.lower() == "button":
+            return await client.wait_for('button_press', check=_check, timeout=timeout)
+        if event_name.lower() == "select":
+            return await client.wait_for("menu_select", check=_check, timeout=timeout)
+        if event_name.lower() == "component":
+            return await client.wait_for("component", check=_check, timeout=timeout)
         
         raise InvalidEvent(event_name, ["button", "select", "component"])
 
