@@ -439,7 +439,10 @@ class BaseCommand():
             raise WrongType("name", value, "str")
         if len(value) > 32 or len(value) < 1:
             raise InvalidLength("name", 1, 32)
-        self._json["name"] = format_name(value)
+        if self.command_type == CommandType.SLASH:
+            self._json["name"] = format_name(value)
+        else:
+            self._json["name"] = value
     @property
     def description(self) -> str:
         """The description of the command
@@ -584,8 +587,8 @@ class ContextCommand(BaseCommand):
         
 class UserCommand(ContextCommand):
     def __init__(self, callback, name=MISSING, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
-        super().__init__(CommandType.USER, callback, name, guild_ids, default_permission, guild_permissions)
+        ContextCommand.__init__(self, CommandType.USER, callback, name, guild_ids, default_permission, guild_permissions)
 
 class MessageCommand(ContextCommand):
     def __init__(self, callback, name=MISSING, guild_ids = MISSING, default_permission = True, guild_permissions = MISSING) -> None:
-        super().__init__(CommandType.MESSAGE, callback, name, guild_ids, default_permission, guild_permissions)
\ No newline at end of file
+        ContextCommand.__init__(self, CommandType.MESSAGE, callback, name, guild_ids, default_permission, guild_permissions)
\ No newline at end of file
